EditorSettings class

Constructors

EditorSettings({String? initialContent, String? placeholder, bool autoFocus = false, int? maxLength})
const

Properties

autoFocus bool
final
hashCode int
The hash code for this object.
no setterinherited
initialContent String?
final
maxLength int?
final
placeholder String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited