HtmlEditorController class

Constructors

HtmlEditorController()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

alignCenter() Future<void>
Align text center
alignLeft() Future<void>
Align text left
alignRight() Future<void>
Align text right
changeTextColor(Color color) Future<void>
Change text color
clear() Future<void>
Clear all content
execCommand(String command, [String? value]) Future<void>
Execute a formatting command
getHtml() Future<String>
Get HTML content
Insert link
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBold() Future<void>
Set bold formatting
setFontSize(String fontSize) Future<void>
Change font size
setHtml(String html) Future<void>
Set HTML content
setItalic() Future<void>
Set italic formatting
setUnderline() Future<void>
Set underline formatting
setWebViewController(WebViewController controller) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited