ToolbarSettings class

Constructors

ToolbarSettings({bool showToolbar = true, bool showBold = true, bool showItalic = true, bool showUnderline = true, bool showAlignment = true, bool showLink = true, bool showTextColor = true, bool showFontSize = true, bool showLists = true, bool showUndo = true, bool showClear = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAlignment bool
final
showBold bool
final
showClear bool
final
showFontSize bool
final
showItalic bool
final
final
showLists bool
final
showTextColor bool
final
showToolbar bool
final
showUnderline bool
final
showUndo bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited